
#source("http://bioconductor.org/biocLite.R")
#biocLite("rGADEM","MotIV","seqLogo","Biostrings","motifStack","BSgenome.Mmusculus.UCSC.mm9","GenomicRanges")
#install.packages("muscle")

library(rGADEM)
library(MotIV)
library(seqLogo)
library(Biostrings)
library(motifStack)
library(muscle)
library(GenomicRanges)
library(BSgenome.Mmusculus.UCSC.mm9)

###Biostrings & BSgenome.Mmusculus.UCSC.mm9 ###
BED<-read.table("GSE46047_GR_peaks_mouse_liver_mm9.txt",header=FALSE,sep="\t")
gr <- GRanges(seqnames=as.factor(BED[,1]), ranges=IRanges(start=as.numeric(BED[,2]), end=as.numeric(BED[,3])))

gr_fasta_1000 <- getSeq(Mmusculus, gr[1:1000])

names(gr_fasta_1000)<-paste(as.character(BED[1:1000,1]),"_",as.character(BED[1:1000,2]),"_",as.character(BED[1:1000,3]),sep="")

writeXStringSet(gr_fasta_1000[1:1000], file="GR1000.fa")

gr_fasta_20 <- getSeq(Mmusculus, gr[1:20])

names(gr_fasta_20)<-paste(as.character(BED[1:20,1]),"_",as.character(BED[1:20,2]),"_",as.character(BED[1:20,3]),sep="")

writeXStringSet(gr_fasta_20[1:20], file="GR20.fa")

###muscle###
muscle("GR_phylo.fasta" , out = "aln_GRphylo.fa")
GR <- readDNAStringSet("aln_GRphylo.fa", "fasta") 

get_names_phylo<-function(name){
	return(paste(unlist(strsplit(name," "))[2:6],sep=" ",collapse=" "))
}
names(GR)<-sapply(names(GR),get_names_phylo)

masim <- sapply(names(GR), function(x) sapply(names(GR), function(y) pid(PairwiseAlignedXStringSet(GR[[x]], GR[[y]]), type="PID2")))
masim
madist <- 1-(masim/100)
madist
heatmap(madist,mar=c(15,15),sym=T)

par(mar=c(5,5,5,20))
disttree <- hclust(as.dist(madist))
plot(as.dendrogram(disttree), edgePar=list(col=3, lwd=4), horiz=T,mar=c(10,10)) 


####motifStack###
par(mar=c(4,4,4,4),mfrow=c(2,1))
pfm<-consensusMatrix(GR)[1:4,3500:3600]
motif <- new("pfm", mat=sweep(pfm,2,colSums(pfm),FUN="/"), name="GR mRNA alignment logo 3500:3600")
plot(motif)
pfm<-consensusMatrix(GR)[1:4,3600:3700]
motif <- new("pfm", mat=sweep(pfm,2,colSums(pfm),FUN="/"), name="GR mRNA alignment logo 3600:3700")
plot(motif)


###rGADEM###	

BED<-read.table("GSE46047_GR_peaks_mouse_liver_mm9.txt",header=FALSE,sep="\t")
BED<-data.frame(chr=as.factor(BED[,1]),start=as.numeric(BED[,2]),end=as.numeric(BED[,3]))
	
rgBED<-IRanges(start=BED[1:500,2],end=BED[1:500,3])
Sequences<-RangedData(rgBED,space=BED[1:500,1])
gadem<-GADEM(Sequences,verbose=1,genome=Mmusculus)
motifs <- getPWM(gadem) 
print(motifs)
	
###MotIV###
analysis.jaspar <- motifMatch(motifs)
summary(analysis.jaspar)

plot(analysis.jaspar, ncol = 2, top = 10, rev = FALSE, main = "Logo GR CHiP 500 sites", bysim = TRUE)
 
f.NR3C1<- setFilter( tfname="NR3C1", top=5, evalueMax=10^-5)
f.Stat3 <- setFilter (tfname="Stat3", top=5)
f.NR3C1.Stat3 <- f.NR3C1 | f.Stat3
NR3C1.filter <- filter(analysis.jaspar, f.NR3C1.Stat3 , exact=FALSE, verbose=TRUE)
NR3C1.filter.combine <- combineMotifs(NR3C1.filter, c(f.NR3C1, f.Stat3), exact=FALSE, name=c("NR3C1", "Stat3"), verbose=TRUE)

plot(NR3C1.filter.combine ,gadem,ncol=2, type="distribution", correction=TRUE, group=FALSE, bysim=TRUE, strand=FALSE, sort=TRUE, main="Distribution of NR3C1")

plot(NR3C1.filter.combine ,gadem,type="distance", correction=TRUE, group=TRUE, bysim=TRUE, main="Distance between NR3C1 and Stat3", strand=FALSE, xlim=c(-100,100), bw=8)


